[empathy/gnome-2-28] Respect "DisableCombineConsecutive" adium theme setting. Fixes bug #596317



commit fc27fecb52fe108782e9835bad6c7256d38d6d72
Author: Xavier Claessens <xclaesse gmail com>
Date:   Mon Sep 28 09:52:41 2009 +0200

    Respect "DisableCombineConsecutive" adium theme setting. Fixes bug #596317

 libempathy-gtk/empathy-theme-adium.c |    9 ++++++---
 1 files changed, 6 insertions(+), 3 deletions(-)
---
diff --git a/libempathy-gtk/empathy-theme-adium.c b/libempathy-gtk/empathy-theme-adium.c
index f4779da..edb0186 100644
--- a/libempathy-gtk/empathy-theme-adium.c
+++ b/libempathy-gtk/empathy-theme-adium.c
@@ -603,12 +603,15 @@ theme_adium_append_message (EmpathyChatView *view,
 
 	/* We want to join this message with the last one if
 	 * - senders are the same contact,
 	 * - last message was recieved recently, and
 	 * - last message and this message both are/aren't backlog */
 	is_backlog = empathy_message_is_backlog (msg);
 	consecutive = empathy_contact_equal (priv->last_contact, sender) &&
 		(timestamp - priv->last_timestamp < MESSAGE_JOIN_PERIOD) &&
-		(is_backlog == priv->last_is_backlog);
+		(is_backlog == priv->last_is_backlog) &&
+		!tp_asv_get_boolean (priv->data->info,
+				     "DisableCombineConsecutive", NULL);
 
 	/* Define message classes */
 	message_classes = g_string_new ("message");
@@ -603,12 +603,15 @@ theme_adium_append_message (EmpathyChatView *view,
 	/* We want to join this message with the last one if
 	 * - senders are the same contact,
-	 * - last message was recieved recently, and
-	 * - last message and this message both are/aren't backlog */
+	 * - last message was recieved recently,
+	 * - last message and this message both are/aren't backlog, and
+	 * - DisableCombineConsecutive is not set in theme's settings */
 	is_backlog = empathy_message_is_backlog (msg);
 	consecutive = empathy_contact_equal (priv->last_contact, sender) &&



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]